@@ -1,4 +1,4 @@
-"""Main package"""
+"""OOMMF calculator."""
 import pytest
 import pkg_resources
 import oommfc.oommf
@@ -11,7 +11,29 @@ from .evolvers import (CGEvolver, EulerEvolver, RungeKuttaEvolver,
                        Xf_ThermHeunEvolver, Xf_ThermSpinXferEvolver)
 
 __version__ = pkg_resources.get_distribution(__name__).version
+
 runner = oommfc.oommf.oommf.Runner()
+"""Controls the default runner.
+
+``runner`` gives access to the default runner OOMMF used by ``oommfc``. For
+details refer to ``oommfc.runner.Runner``.
+
+Examples
+--------
+``runner.runner``
+    Returns the default runner; selects the best available runner if unset. A
+    different ``OOMMFRunner`` can be passed to be used instead. The new runner
+    is tested first.
+
+``runner.autoselect_runner()``
+    Lets ``oommfc`` select the best runner. Can be used to reset the runner
+    after overwriting it manually.
+
+See Also
+--------
+:py:class:`~oommfc.oommf.Runner`
+
+"""
 
 
 def test():
