@@ -46,7 +46,7 @@ class Driver(mm.Driver):
 
     def drive(self, system, /, dirname='.', append=True, fixed_subregions=None,
               compute=None, output_step=False, n_threads=None, runner=None,
-              **kwargs):
+              ovf_format='bin8', verbose=1, **kwargs):
         """Drives the system in phase space.
 
         Takes ``micromagneticmodel.System`` and drives it in the phase space.
@@ -91,6 +91,19 @@ class Driver(mm.Driver):
             ``None``, OOMMF runner will be found automatically. Defaults to
             ``None``.
 
+        ovf_format : str
+
+            Format of the magnetisation output files written by OOMMF. Can be
+            one of ``'bin8'`` (binary, double precision), ``'bin4'`` (binary,
+            single precision) or ``'txt'`` (text-based, double precision).
+            Defaults to ``'bin8'``.
+
+        verbose : int, optional
+
+            If ``verbose=0``, no output is printed. For ``verbose>=1``
+            information about the OOMMF runner and the runtime is printed to
+            stdout. Defaults is ``verbose=1``.
+
         Raises
         ------
         FileExistsError
@@ -173,8 +186,8 @@ class Driver(mm.Driver):
 
         # compute tlist for time-dependent field (current)
         for term in system.energy:
-            if (hasattr(term, 'time_dependence')
-                    and callable(term.time_dependence)):
+            if (hasattr(term, 'func')
+                    and callable(term.func)):
                 self._time_dependence(term=term, **kwargs)
 
         # Change directory to workingdir
@@ -184,7 +197,7 @@ class Driver(mm.Driver):
             jsonfilename = 'info.json'
 
             # Generate and save mif file.
-            mif = oc.scripts.system_script(system)
+            mif = oc.scripts.system_script(system, ovf_format=ovf_format)
             mif += oc.scripts.driver_script(self, system,
                                             fixed_subregions=fixed_subregions,
                                             output_step=output_step,
@@ -194,8 +207,8 @@ class Driver(mm.Driver):
 
             # free memory
             for term in system.energy:
-                if (hasattr(term, 'time_dependence')
-                        and callable(term.time_dependence)):
+                if (hasattr(term, 'func')
+                        and callable(term.func)):
                     del term.tlist
                     del term.dtlist
                     del mif
@@ -212,20 +225,10 @@ class Driver(mm.Driver):
                 with open(jsonfilename, 'w') as jsonfile:
                     jsonfile.write(json.dumps(info))
 
-            # Get right OOMMF runner depending on whether there is DMI.
             if runner is None:
-                if sys.platform != 'win32':
-                    runner = oc.runner.runner
-                else:
-                    if hasattr(system.energy, 'dmi'):
-                        if (system.energy.dmi.crystalclass in ['Cnv', 'Cnv_z']
-                                and system.m.mesh.bc == ''):
-                            runner = oc.runner.runner
-                        else:
-                            runner = oc.oommf.DockerOOMMFRunner()
-                    else:
-                        runner = oc.runner.runner
-            runner.call(argstr=miffilename, n_threads=n_threads)
+                runner = oc.runner.runner
+            runner.call(argstr=miffilename, n_threads=n_threads,
+                        verbose=verbose)
 
             # Update system's m and datatable attributes if the derivation of
             # E, Heff, or energy density was not asked.
@@ -242,7 +245,7 @@ class Driver(mm.Driver):
                 elif isinstance(self, oc.MinDriver):
                     x = 'iteration'
                 elif isinstance(self, oc.HysteresisDriver):
-                    x = 'B'
+                    x = 'B_hysteresis'
                 system.table = ut.Table.fromfile(f'{system.name}.odt', x=x)
 
         if compute is None:
@@ -261,12 +264,12 @@ class Driver(mm.Driver):
             msg = (f'Time-dependent term {term.__class__.__name__=} must be '
                    'used with time driver.')
             raise RuntimeError(msg)
-        ts = np.arange(0, tmax + term.tstep, term.tstep)
-        try:  # vector output from term.time_dependence
-            tlist = [list(term.time_dependence(t)) for t in ts]
-            dtlist = (np.gradient(tlist)[0] / term.tstep).tolist()
-        except TypeError:
-            tlist = [term.time_dependence(t) for t in ts]
-            dtlist = list(np.gradient(tlist) / term.tstep)
+        ts = np.arange(0, tmax + term.dt, term.dt)
+        try:  # vector output from term.func
+            tlist = [list(term.func(t)) for t in ts]
+            dtlist = (np.gradient(tlist)[0] / term.dt).tolist()
+        except TypeError:  # scalar output from term.func
+            tlist = [term.func(t) for t in ts]
+            dtlist = list(np.gradient(tlist) / term.dt)
         term.tlist = tlist
         term.dtlist = dtlist
