@@ -1,3 +1,3 @@
 """OOMMF driving utility"""
 from .oommf import (OOMMFRunner, TclOOMMFRunner, ExeOOMMFRunner,
-                    DockerOOMMFRunner, overhead)
+                    DockerOOMMFRunner, Runner, overhead)
