@@ -16,7 +16,18 @@ log = logging.getLogger('oommfc')
 class OOMMFRunner(metaclass=abc.ABCMeta):
     """Abstract class for running OOMMF."""
 
-    def call(self, argstr, need_stderr=False, n_threads=None):
+    def __del__(self):
+        """Kill all OOMMF applications when object goes out of scope.
+
+        On Windows we must kill OOMMF after each call because file ownerships
+        are otherwise not correct. As a consequence ``oommfc.delete`` does not
+        work without killing.
+
+        """
+        if sys.platform != 'win32':
+            self._kill()
+
+    def call(self, argstr, need_stderr=False, n_threads=None, verbose=1):
         """Call OOMMF by passing ``argstr`` to OOMMF.
 
         Parameters
@@ -25,11 +36,17 @@ class OOMMFRunner(metaclass=abc.ABCMeta):
 
             Argument string passed to OOMMF.
 
-        need_stderr : bool
+        need_stderr : bool, optional
 
             If ``need_stderr=True``, standard error is captured. Defaults to
             ``False``.
 
+        verbose : int, optional
+
+            If ``verbose=0``, no output is printed. For ``verbose>=1``
+            information about the OOMMF runner and the runtime is printed to
+            stdout. Defaults is ``verbose=1``.
+
         Raises
         ------
         RuntimeError
@@ -54,22 +71,26 @@ class OOMMFRunner(metaclass=abc.ABCMeta):
         CompletedProcess(...)
 
         """
-        now = datetime.datetime.now()
-        timestamp = '{}/{:02d}/{:02d} {:02d}:{:02d}'.format(now.year,
-                                                            now.month,
-                                                            now.day,
-                                                            now.hour,
-                                                            now.minute)
-        print(f'Running OOMMF ({self.__class__.__name__}) [{timestamp}]... ',
-              end='')
+        if verbose >= 1:
+            now = datetime.datetime.now()
+            timestamp = '{}/{:02d}/{:02d} {:02d}:{:02d}'.format(now.year,
+                                                                now.month,
+                                                                now.day,
+                                                                now.hour,
+                                                                now.minute)
+            print((f'Running OOMMF ({self.__class__.__name__})'
+                   f'[{timestamp}]... '),
+                  end='')
+            tic = time.time()
 
-        tic = time.time()
         res = self._call(argstr=argstr, need_stderr=need_stderr,
                          n_threads=n_threads)
-        self._kill()  # kill OOMMF (mostly needed on Windows)
-        toc = time.time()
-        seconds = '({:0.1f} s)'.format(toc - tic)
-        print(seconds)  # append seconds to the previous print.
+        if sys.platform == 'win32':
+            self._kill()  # required for oc.delete; oommf keeps file ownership
+        if verbose >= 1:
+            toc = time.time()
+            seconds = '({:0.1f} s)'.format(toc - tic)
+            print(seconds)  # append seconds to the previous print.
 
         if res.returncode != 0:
             if sys.platform != 'win32':
@@ -133,7 +154,7 @@ class OOMMFRunner(metaclass=abc.ABCMeta):
 
         """
         res = self.call(argstr='+version', need_stderr=True)
-        return res.stderr.decode('utf-8').split('oommf.tcl')[-1].strip()
+        return res.stderr.decode('utf-8').split('OOMMF')[-1].strip()
 
     @property
     def platform(self):
@@ -157,8 +178,9 @@ class OOMMFRunner(metaclass=abc.ABCMeta):
         '...'
 
         """
+        # in 2.0a3 platform information is written to stdout
         res = self.call(argstr='+platform', need_stderr=True)
-        return res.stderr.decode('utf-8')
+        return res.stdout.decode('utf-8')
 
     @property
     def status(self):
@@ -199,28 +221,27 @@ class OOMMFRunner(metaclass=abc.ABCMeta):
 
 
 @uu.inherit_docs
-class TclOOMMFRunner(OOMMFRunner):
-    """OOMMF runner using path to ``oommf.tcl``.
+class NativeOOMMFRunner(OOMMFRunner):
+    """OOMMF runner using oommf installed on the system.
 
-    Parameters
-    ----------
-    oommf_tcl: str
-
-        Path to ``oommf.tcl``file.
+    Base class for ``TclOOMMFRunner`` and ``ExeOOMMFRunner``.
+    Derived classes must implement a ``List`` ``self.oommf``.
 
     """
 
-    def __init__(self, oommf_tcl):
-        self.oommf_tcl = oommf_tcl  # a path to oommf.tcl
+    def __init__(self):
+        # oommf launchhost gets stuck on Windows
+        # -> it is not possible to run multiple calculations in parallel
         if sys.platform != 'win32':
-            launchhost = sp.run(['tclsh', self.oommf_tcl, 'launchhost', '0'],
+            launchhost = sp.run([*self.oommf, 'launchhost', '0'],
                                 stdout=sp.PIPE)
             port = launchhost.stdout.decode('utf-8', 'replace').strip('\n')
             self.env = dict(OOMMF_HOSTPORT=port, **os.environ)
+        else:
+            self.env = os.environ
 
     def _call(self, argstr, need_stderr=False, n_threads=None):
-        cmd = ['tclsh', self.oommf_tcl, 'boxsi', '+fg',
-               argstr, '-exitondone', '1']
+        cmd = [*self.oommf, 'boxsi', '+fg', argstr, '-exitondone', '1']
 
         # Not clear why we cannot get stderr and stdout on win32. Calls to
         # OOMMF get stuck.
@@ -231,17 +252,28 @@ class TclOOMMFRunner(OOMMFRunner):
         if n_threads is not None:
             cmd += ['-threads', str(n_threads)]
 
-        if sys.platform != 'win32':
-            return sp.run(cmd, stdout=stdout, stderr=stderr, env=self.env)
-        else:
-            return sp.run(cmd, stdout=stdout, stderr=stderr)
+        return sp.run(cmd, stdout=stdout, stderr=stderr, env=self.env)
 
     def _kill(self, targets=('all',)):
-        if sys.platform != 'win32':
-            sp.run(['tclsh', self.oommf_tcl, 'killoommf'] + list(targets),
-                   env=self.env)
-        else:
-            sp.run(['tclsh', self.oommf_tcl, 'killoommf'] + list(targets))
+        sp.run([*self.oommf, 'killoommf', '-q'] + list(targets), env=self.env)
+
+
+@uu.inherit_docs
+class TclOOMMFRunner(NativeOOMMFRunner):
+    """OOMMF runner using path to ``oommf.tcl``.
+
+    Parameters
+    ----------
+    oommf_tcl: str
+
+        Path to ``oommf.tcl`` file.
+
+    """
+
+    def __init__(self, oommf_tcl):
+        self.oommf_tcl = oommf_tcl  # a path to oommf.tcl
+        self.oommf = ['tclsh', self.oommf_tcl]
+        super().__init__()
 
     def errors(self):
         errors_file = os.path.join(os.path.dirname(self.oommf_tcl),
@@ -256,7 +288,7 @@ class TclOOMMFRunner(OOMMFRunner):
 
 
 @uu.inherit_docs
-class ExeOOMMFRunner(OOMMFRunner):
+class ExeOOMMFRunner(NativeOOMMFRunner):
     """OOMMF runner using OOMMF executable, which can be found on $PATH.
 
     Parameters
@@ -269,22 +301,8 @@ class ExeOOMMFRunner(OOMMFRunner):
 
     def __init__(self, oommf_exe='oommf'):
         self.oommf_exe = oommf_exe
-        launchhost = sp.run([self.oommf_exe, 'launchhost', '0'],
-                            stdout=sp.PIPE)
-        port = launchhost.stdout.decode('utf-8', 'replace').strip('\n')
-        self.env = dict(OOMMF_HOSTPORT=port, **os.environ)
-
-    def _call(self, argstr, need_stderr=False, n_threads=None):
-        # Here we might need stderr = stdot = None like in
-        # TclOOMMFRunner for Windows.  This is not clear because we
-        # never use ExeOOMMFRunner on Windows.
-        cmd = [self.oommf_exe, 'boxsi', '+fg', argstr, '-exitondone', '1']
-        if n_threads is not None:
-            cmd += ['-threads', str(n_threads)]
-        return sp.run(cmd, stdout=sp.PIPE, stderr=sp.PIPE, env=self.env)
-
-    def _kill(self, targets=('all',)):
-        sp.run([self.oommf_exe, 'killoommf'] + list(targets), env=self.env)
+        self.oommf = [oommf_exe]
+        super().__init__()
 
     def errors(self):
         try:
@@ -451,15 +469,20 @@ class Runner:
         True
 
         """
-        log.debug('Starting autoselect_runner: cache_runner=%(cache_runner)s, '
-                  'envvar=%(envvar)s, oommf_exe=%(oommf_exe)s, '
-                  'docker_exe=%(docker_exe)s)',
-                  {'cache_runner': self.cache_runner, 'envvar': self.envvar,
-                   'oommf_exe': self.oommf_exe, 'docker_exe': self.docker_exe})
+        log.debug(
+            'Starting autoselect_runner: cache_runner=%(cache_runner)s, '
+            'envvar=%(envvar)s, oommf_exe=%(oommf_exe)s, '
+            'docker_exe=%(docker_exe)s)', {
+                'cache_runner': self.cache_runner,
+                'envvar': self.envvar,
+                'oommf_exe': self.oommf_exe,
+                'docker_exe': self.docker_exe
+            })
 
         # Check for the OOMMFTCL environment variable pointing to oommf.tcl.
-        log.debug('Step 1: Checking for the self.envvar=%(envvar)s environment'
-                  ' variable pointing to oommf.tcl.', {'envvar': self.envvar})
+        log.debug(
+            'Step 1: Checking for the self.envvar=%(envvar)s environment'
+            ' variable pointing to oommf.tcl.', {'envvar': self.envvar})
         oommf_tcl = os.environ.get(self.envvar, None)
         if oommf_tcl is not None:
             cmd = [
@@ -474,27 +497,17 @@ class Runner:
                 if res.returncode:
                     log.warning(
                         'OOMMFTCL is set, but OOMMF could not be run.\n'
-                        'stdout:\n%(stdout)s\nstderr:\n%(sdterr)s',
-                        {'stdout': res.stdout, 'stderr': res.stderr})
+                        'stdout:\n%(stdout)s\nstderr:\n%(sdterr)s', {
+                            'stdout': res.stdout,
+                            'stderr': res.stderr
+                        })
                 else:
                     self._runner = TclOOMMFRunner(oommf_tcl)
                     return
 
-        # OOMMF is installed via conda and oommf.tcl is in opt/oommf (Windows).
-        # This would probably also work on MacOS/Linux, but on these operating
-        # systems, when installed via conda, we use 'oommf' executable.
-        log.debug(
-            "Step 2: are we on Windows and oommf is installed via conda?")
-        if sys.platform == 'win32' and \
-           os.path.isdir(os.path.join(sys.prefix, 'conda-meta')):
-            oommf_tcl = os.path.join(sys.prefix, 'opt', 'oommf', 'oommf.tcl')
-            if os.path.isfile(oommf_tcl):
-                self._runner = TclOOMMFRunner(oommf_tcl)
-                return
-
         # OOMMF available as an executable - in a conda env on Mac/Linux, or
         # oommf installed separately.
-        log.debug('Step 3: is oommf_exe=%(oommf_exe)s in PATH? '
+        log.debug('Step 2: is oommf_exe=%(oommf_exe)s in PATH? '
                   'Could be from conda env or manual install.',
                   {'oommf_exe': self.oommf_exe})
         oommf_exe = shutil.which(self.oommf_exe)
@@ -502,10 +515,14 @@ class Runner:
                   {'oommf_exe': oommf_exe})
         if oommf_exe:
             cmd = [oommf_exe, 'boxsi',
-                   '+fg', '+version', '-exitondone', '1']
+                   '+fg', '+version', '-exitondone', '1', '-kill', 'all']
+
+            stdout = stderr = sp.PIPE
+            if sys.platform == 'win32':
+                stdout = stderr = None  # pragma: no cover
 
             log.debug("Attempt command call")  # DEBUG
-            res = sp.run(cmd, stdout=sp.PIPE, stderr=sp.PIPE)
+            res = sp.run(cmd, stdout=stdout, stderr=stderr)
             log.debug(res)
 
             if res.returncode == 0:
@@ -520,7 +537,7 @@ class Runner:
                     pass
 
         # Check for docker to run OOMMF in a docker image.
-        log.debug("Step 4: Can we use docker to host OOMMF?"
+        log.debug("Step 3: Can we use docker to host OOMMF?"
                   ' ("docker_exe=%(docker_exe)s")',
                   {'docker_exe': self.docker_exe})
         cmd = [self.docker_exe, 'images']
