@@ -42,7 +42,8 @@ def exchange_script(term, system):
         mif += '}\n\n'
 
     elif isinstance(term.A, df.Field):
-        Amif, Aname = oc.scripts.setup_scalar_parameter(term.A, 'exchange_A')
+        Amif, Aname = oc.scripts.setup_scalar_parameter(term.A,
+                                                        f'{term.name}_A')
         mif = Amif
         mif += '# ExchangePtwise\n'
         mif += f'Specify Oxs_ExchangePtwise:{term.name} {{\n'
@@ -53,14 +54,18 @@ def exchange_script(term, system):
 
 
 def zeeman_script(term, system):
-    Hmif, Hname = oc.scripts.setup_vector_parameter(term.H, 'zeeman_H')
+    Hmif, Hname = oc.scripts.setup_vector_parameter(term.H, f'{term.name}_H')
 
     mif = ''
     mif += Hmif
 
-    if isinstance(term.wave, str):
+    if isinstance(term.wave, str) or isinstance(term.func, str):
+        if isinstance(term.wave, str):
+            warnings.warn(
+                'Parameter `wave` is deprecated; use `func` instead.',
+                FutureWarning)
         if isinstance(term.H, (df.Field, dict)):
-            if term.wave == 'sin':
+            if term.wave == 'sin' or term.func == 'sin':
                 mif += 'proc TimeFunction { total_time } {\n'
                 mif += '  set PI [expr {4*atan(1.)}]\n'
                 mif += f'  set w [expr {{ {term.f}*2*$PI }}]\n'
@@ -74,7 +79,7 @@ def zeeman_script(term, system):
                         '$dft 0 0 0 $dft 0 0 0 $dft ] \n')
                 mif += '}\n\n'
 
-            elif term.wave == 'sinc':
+            elif term.wave == 'sinc' or term.func == 'sinc':
                 mif += 'proc TimeFunction { total_time } {\n'
                 mif += '  set PI [expr {4*atan(1.)}]\n'
                 mif += f'  set w [expr {{ {term.f}*2*$PI }}]\n'
@@ -101,7 +106,7 @@ def zeeman_script(term, system):
             mif += f'  field {Hname}\n'
             mif += '}\n\n'
         else:
-            if term.wave == 'sin':
+            if term.wave == 'sin' or term.func == 'sin':
                 mif += 'proc TimeFunction { total_time } {\n'
                 mif += '  set PI [expr {4*atan(1.)}]\n'
                 mif += f'  set w [expr {{ {term.f}*2*$PI }}]\n'
@@ -117,7 +122,7 @@ def zeeman_script(term, system):
                 mif += f'  set dHz [expr {{ {term.H[2]}*$df }}]\n'
                 mif += '  return [list $Hx $Hy $Hz $dHx $dHy $dHz ] \n'
                 mif += '}\n\n'
-            elif term.wave == 'sinc':
+            elif term.wave == 'sinc' or term.func == 'sinc':
                 mif += 'proc TimeFunction { total_time } {\n'
                 mif += '  set PI [expr {4*atan(1.)}]\n'
                 mif += f'  set w [expr {{ {term.f}*2*$PI }}]\n'
@@ -147,7 +152,7 @@ def zeeman_script(term, system):
     elif hasattr(term, 'tlist'):
         if isinstance(term.H, (df.Field, dict)):
             mif += 'proc TimeFunction { total_time } {\n'
-            mif += f'  set tstep {term.tstep}\n'
+            mif += f'  set tstep {term.dt}\n'
             mif += '  set index [expr round($total_time/$tstep)]\n'
             tstr = ' '.join(map(str, term.tlist))
             for char, replacement in [[',', ''], ['[', '{ '], [']', ' }']]:
@@ -180,7 +185,7 @@ def zeeman_script(term, system):
             mif += '}\n\n'
         else:
             mif += 'proc TimeFunction { total_time } {\n'
-            mif += f'  set tstep {term.tstep}\n'
+            mif += f'  set tstep {term.dt}\n'
             mif += '  set index [expr round($total_time/$tstep)]\n'
             mif += f'  set H_t_fac {{ {" ".join(map(str, term.tlist))} }}\n'
             mif += f'  set dH_t_fac {{ {" ".join(map(str, term.dtlist))} }}\n'
@@ -201,10 +206,11 @@ def zeeman_script(term, system):
             mif += f'  script TimeFunction\n'
             mif += '}\n\n'
     elif isinstance(term.tcl_strings, dict):
-        mif += term.tcl_strings['proc']
+        mif += term.tcl_strings['script']
         mif += f'\n# {term.tcl_strings["energy"][4:]}\n'  # 3.9 removeprefix
         mif += f'Specify {term.tcl_strings["energy"]}:{term.name} {{\n'
-        for key in ['type', 'script_args', 'script']:
+        mif += f'  script {term.tcl_strings["script_name"]}\n'
+        for key in ['type', 'script_args']:
             try:
                 mif += f'  {key} {term.tcl_strings[key]}\n'
             except KeyError:
@@ -251,18 +257,11 @@ def dmi_script(term, system):
             tcc = 'D2d_z'
         oxs = f'Oxs_DMI_{tcc}'
     elif (tcc := term.crystalclass) in ['Cnv_x', 'Cnv_y', 'Cnv_z', 'Cnv']:
-        if sys.platform == 'win32' and system.m.mesh.bc == '':
-            if tcc in ['Cnv_x', 'Cnv_y']:
-                msg = (f'Crystalclass {tcc} is not supported on Windows.'
-                       'Use Docker to run OOMMF.')
-                raise RuntimeError(msg)
-            oxs = 'Oxs_DMExchange6Ngbr'
-        else:
-            if tcc == 'Cnv':
-                msg = 'Use of `Cnv` is deprecated; use `Cnv_z` instead.'
-                warnings.warn(msg, FutureWarning)
-                tcc = 'Cnv_z'
-            oxs = f'Oxs_DMI_{tcc}'
+        if tcc == 'Cnv':
+            msg = 'Use of `Cnv` is deprecated; use `Cnv_z` instead.'
+            warnings.warn(msg, FutureWarning)
+            tcc = 'Cnv_z'
+        oxs = f'Oxs_DMI_{tcc}'
 
     mif = f'# DMI of crystallographic class {term.crystalclass}\n'
     mif += f'Specify {oxs}:{term.name} {{\n'
@@ -300,12 +299,14 @@ def dmi_script(term, system):
 
 
 def uniaxialanisotropy_script(term, system):
-    umif, uname = oc.scripts.setup_vector_parameter(term.u, 'ua_u')
+    umif, uname = oc.scripts.setup_vector_parameter(term.u, f'{term.name}_u')
 
     # Determine if higher-order anisotropy is defined
     if isinstance(term.K2, (numbers.Real, dict, df.Field)):
-        k1mif, k1name = oc.scripts.setup_scalar_parameter(term.K1, 'ua_K1')
-        k2mif, k2name = oc.scripts.setup_scalar_parameter(term.K2, 'ua_K2')
+        k1mif, k1name = oc.scripts.setup_scalar_parameter(term.K1,
+                                                          f'{term.name}_K1')
+        k2mif, k2name = oc.scripts.setup_scalar_parameter(term.K2,
+                                                          f'{term.name}_K2')
 
         mif = ''
         mif += k1mif
@@ -319,7 +320,8 @@ def uniaxialanisotropy_script(term, system):
         mif += '}\n\n'
 
     else:
-        kmif, kname = oc.scripts.setup_scalar_parameter(term.K, 'ua_K')
+        kmif, kname = oc.scripts.setup_scalar_parameter(term.K,
+                                                        f'{term.name}_K')
 
         mif = ''
         mif += kmif
@@ -334,9 +336,11 @@ def uniaxialanisotropy_script(term, system):
 
 
 def cubicanisotropy_script(term, system):
-    kmif, kname = oc.scripts.setup_scalar_parameter(term.K, 'ca_K')
-    u1mif, u1name = oc.scripts.setup_vector_parameter(term.u1, 'ca_u1')
-    u2mif, u2name = oc.scripts.setup_vector_parameter(term.u2, 'ca_u2')
+    kmif, kname = oc.scripts.setup_scalar_parameter(term.K, f'{term.name}_K')
+    u1mif, u1name = oc.scripts.setup_vector_parameter(term.u1,
+                                                      f'{term.name}_u1')
+    u2mif, u2name = oc.scripts.setup_vector_parameter(term.u2,
+                                                      f'{term.name}_u2')
 
     mif = ''
     mif += kmif
@@ -353,12 +357,14 @@ def cubicanisotropy_script(term, system):
 
 
 def magnetoelastic_script(term, system):
-    B1mif, B1name = oc.scripts.setup_scalar_parameter(term.B1, 'mel_B1')
-    B2mif, B2name = oc.scripts.setup_scalar_parameter(term.B2, 'mel_B2')
+    B1mif, B1name = oc.scripts.setup_scalar_parameter(term.B1,
+                                                      f'{term.name}_B1')
+    B2mif, B2name = oc.scripts.setup_scalar_parameter(term.B2,
+                                                      f'{term.name}_B2')
     ediagmif, ediagname = oc.scripts.setup_vector_parameter(
-        term.e_diag, 'mel_ediag')
+        term.e_diag, f'{term.name}_ediag')
     eoffdiagmif, eoffdiagname = oc.scripts.setup_vector_parameter(
-        term.e_offdiag, 'mel_eoffdiag')
+        term.e_offdiag, f'{term.name}_eoffdiag')
 
     mif = ''
     mif += B1mif
